typedef union {
	char *string;
	RC_SECTION *section;
	RC_STMT *stmt;
	struct { RC_STMT *head; RC_STMT *tail; } stmtlist;
	RC_COND cond;
	RC_RULE rule;
	RC_NODE *node;
	RC_REGEX *regex;
	int num;
	struct {
		int part;
		RC_REGEX *key;
		char *string;
	} msgpart;
	RC_LOC loc;
	struct {
		size_t line;
		char *name;
	} begin_sec;
	LIST *list;
} YYSTYPE;
#define	EOL	257
#define	T_BEGIN	258
#define	T_END	259
#define	AND	260
#define	OR	261
#define	IF	262
#define	FI	263
#define	ELSE	264
#define	RULE	265
#define	DONE	266
#define	CALL	267
#define	STOP	268
#define	ADD	269
#define	REMOVE	270
#define	MODIFY	271
#define	IDENT	272
#define	STRING	273
#define	REGEX	274
#define	D_BEGIN	275
#define	T_MSGPART	276
#define	NOT	277


extern YYSTYPE rc_yylval;
